# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Basic Service."""

__version__ = "4.0.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .add_country_group_request import AddCountryGroupRequest
from .add_country_group_response import AddCountryGroupResponse
from .config_create import ConfigCreate
from .config_info import ConfigInfo
from .config_update import ConfigUpdate
from .country_group_object import CountryGroupObject
from .country_object import CountryObject
from .error_entity import ErrorEntity
from .field_validation_error import FieldValidationError
from .file_upload_url_info import FileUploadUrlInfo
from .namespace_context import NamespaceContext
from .namespace_context import TypeEnum as NamespaceContextTypeEnum
from .namespace_create import NamespaceCreate
from .namespace_info import NamespaceInfo
from .namespace_info import StatusEnum as NamespaceInfoStatusEnum
from .namespace_publisher_info import NamespacePublisherInfo
from .namespace_simple_info import NamespaceSimpleInfo
from .namespace_status_update import NamespaceStatusUpdate
from .namespace_status_update import StatusEnum as NamespaceStatusUpdateStatusEnum
from .namespace_update import NamespaceUpdate
from .permission import Permission
from .retrieve_country_group_response import RetrieveCountryGroupResponse
from .retrieve_time_response import RetrieveTimeResponse
from .update_country_group_request import UpdateCountryGroupRequest
from .user_profile_admin import UserProfileAdmin
from .user_profile_admin import StatusEnum as UserProfileAdminStatusEnum
from .user_profile_bulk_request import UserProfileBulkRequest
from .user_profile_create import UserProfileCreate
from .user_profile_info import UserProfileInfo
from .user_profile_info import StatusEnum as UserProfileInfoStatusEnum
from .user_profile_private_create import UserProfilePrivateCreate
from .user_profile_private_info import UserProfilePrivateInfo
from .user_profile_private_info import StatusEnum as UserProfilePrivateInfoStatusEnum
from .user_profile_public_info import UserProfilePublicInfo
from .user_profile_status_update import UserProfileStatusUpdate
from .user_profile_status_update import StatusEnum as UserProfileStatusUpdateStatusEnum
from .user_profile_update import UserProfileUpdate
from .user_zip_code import UserZipCode
from .user_zip_code_update import UserZipCodeUpdate
from .validation_error_entity import ValidationErrorEntity
